@@ -2,7 +2,7 @@
 #
 # barriosqdata.py - barrioSquare data access layer
 # 
-# barrioSquare v0.3.3
+# barrioSquare v0.3.4
 # Copyright(c) 2010 Chili Technologies LLC
 # http://www.chilitechno.com/fster
 #
@@ -32,7 +32,7 @@
 # ============================================================================
 # Name        : barriodata.py
 # Author      : Chris J. Burris - chris@chilitechno.com
-# Version     : 0.3.3
+# Version     : 0.3.4
 # Description : barrioSquare
 # ============================================================================
 
@@ -175,6 +175,9 @@ class DataWorkerThread(QtCore.QThread):
 		self.db.setDatabaseName(self.dbFilePath)
 		self.isDbOpen = self.db.open()
 
+                if not self.isDbOpen:
+                        raise Exception("Database not available")
+
 		# init the worker
 		self.worker = DataWorker(self.db)
 		# connect the signal to the slot
@@ -209,6 +212,9 @@ class DataManager(QtCore.QObject):
 		self.db.setDatabaseName(dbFilePath)
 		self.isDbOpen = self.db.open()
 
+                if not self.isDbOpen:
+                        raise Exception("Database not available")
+
 		# setup thread
 		self.insertUpdateDeleteThread = DataWorkerThread()
 		# add a callback to slot
